from setuptools import setup

setup(
    name='fundao2.0',
    version='1.0',
    author='Ojuara Abaporujucaíba',
    author_email='ojuara@araujo.com',
    description='Brincando com distribuição python',
    py_modules = ['ojuara']
)